1 //===--- CGDeclCXX.cpp - Emit LLVM Code for C++ declarations --------------===//
2 //
3 //                     The LLVM Compiler Infrastructure
4 //
5 // This file is distributed under the University of Illinois Open Source
6 // License. See LICENSE.TXT for details.
7 //
8 //===----------------------------------------------------------------------===//
9 //
10 // This contains code dealing with code generation of C++ declarations
11 //
12 //===----------------------------------------------------------------------===//
13 
14 #include "CodeGenFunction.h"
15 #include "CGCXXABI.h"
16 #include "CGObjCRuntime.h"
17 #include "CGOpenMPRuntime.h"
18 #include "clang/Frontend/CodeGenOptions.h"
19 #include "llvm/ADT/StringExtras.h"
20 #include "llvm/IR/Intrinsics.h"
21 #include "llvm/IR/MDBuilder.h"
22 #include "llvm/Support/Path.h"
23 
24 using namespace clang;
25 using namespace CodeGen;
26 
27 static void EmitDeclInit(CodeGenFunction &CGF, const VarDecl &D,
28                          ConstantAddress DeclPtr) {
29   assert(D.hasGlobalStorage() && "VarDecl must have global storage!");
30   assert(!D.getType()->isReferenceType() &&
31          "Should not call EmitDeclInit on a reference!");
32 
33   QualType type = D.getType();
34   LValue lv = CGF.MakeAddrLValue(DeclPtr, type);
35 
36   const Expr *Init = D.getInit();
37   switch (CGF.getEvaluationKind(type)) {
38   case TEK_Scalar: {
39     CodeGenModule &CGM = CGF.CGM;
40     if (lv.isObjCStrong())
41       CGM.getObjCRuntime().EmitObjCGlobalAssign(CGF, CGF.EmitScalarExpr(Init),
42                                                 DeclPtr, D.getTLSKind());
43     else if (lv.isObjCWeak())
44       CGM.getObjCRuntime().EmitObjCWeakAssign(CGF, CGF.EmitScalarExpr(Init),
45                                               DeclPtr);
46     else
47       CGF.EmitScalarInit(Init, &D, lv, false);
48     return;
49   }
50   case TEK_Complex:
51     CGF.EmitComplexExprIntoLValue(Init, lv, /*isInit*/ true);
52     return;
53   case TEK_Aggregate:
54     CGF.EmitAggExpr(Init, AggValueSlot::forLValue(lv,AggValueSlot::IsDestructed,
55                                           AggValueSlot::DoesNotNeedGCBarriers,
56                                                   AggValueSlot::IsNotAliased,
57                                                   AggValueSlot::DoesNotOverlap));
58     return;
59   }
60   llvm_unreachable("bad evaluation kind");
61 }
62 
63 /// Emit code to cause the destruction of the given variable with
64 /// static storage duration.
65 static void EmitDeclDestroy(CodeGenFunction &CGF, const VarDecl &D,
66                             ConstantAddress addr) {
67   CodeGenModule &CGM = CGF.CGM;
68 
69   // FIXME:  __attribute__((cleanup)) ?
70 
71   QualType type = D.getType();
72   QualType::DestructionKind dtorKind = type.isDestructedType();
73 
74   switch (dtorKind) {
75   case QualType::DK_none:
76     return;
77 
78   case QualType::DK_cxx_destructor:
79     break;
80 
81   case QualType::DK_objc_strong_lifetime:
82   case QualType::DK_objc_weak_lifetime:
83   case QualType::DK_nontrivial_c_struct:
84     // We don't care about releasing objects during process teardown.
85     assert(!D.getTLSKind() && "should have rejected this");
86     return;
87   }
88 
89   llvm::Constant *function;
90   llvm::Constant *argument;
91 
92   // Special-case non-array C++ destructors, if they have the right signature.
93   // Under some ABIs, destructors return this instead of void, and cannot be
94   // passed directly to __cxa_atexit if the target does not allow this mismatch.
95   const CXXRecordDecl *Record = type->getAsCXXRecordDecl();
96   bool CanRegisterDestructor =
97       Record && (!CGM.getCXXABI().HasThisReturn(
98                      GlobalDecl(Record->getDestructor(), Dtor_Complete)) ||
99                  CGM.getCXXABI().canCallMismatchedFunctionType());
100   // If __cxa_atexit is disabled via a flag, a different helper function is
101   // generated elsewhere which uses atexit instead, and it takes the destructor
102   // directly.
103   bool UsingExternalHelper = !CGM.getCodeGenOpts().CXAAtExit;
104   if (Record && (CanRegisterDestructor || UsingExternalHelper)) {
105     assert(!Record->hasTrivialDestructor());
106     CXXDestructorDecl *dtor = Record->getDestructor();
107 
108     function = CGM.getAddrOfCXXStructor(dtor, StructorType::Complete);
109     argument = llvm::ConstantExpr::getBitCast(
110         addr.getPointer(), CGF.getTypes().ConvertType(type)->getPointerTo());
111 
112   // Otherwise, the standard logic requires a helper function.
113   } else {
114     function = CodeGenFunction(CGM)
115         .generateDestroyHelper(addr, type, CGF.getDestroyer(dtorKind),
116                                CGF.needsEHCleanup(dtorKind), &D);
117     argument = llvm::Constant::getNullValue(CGF.Int8PtrTy);
118   }
119 
120   CGM.getCXXABI().registerGlobalDtor(CGF, D, function, argument);
121 }
122 
123 /// Emit code to cause the variable at the given address to be considered as
124 /// constant from this point onwards.
125 static void EmitDeclInvariant(CodeGenFunction &CGF, const VarDecl &D,
126                               llvm::Constant *Addr) {
127   // Do not emit the intrinsic if we're not optimizing.
128   if (!CGF.CGM.getCodeGenOpts().OptimizationLevel)
129     return;
130 
131   // Grab the llvm.invariant.start intrinsic.
132   llvm::Intrinsic::ID InvStartID = llvm::Intrinsic::invariant_start;
133   // Overloaded address space type.
134   llvm::Type *ObjectPtr[1] = {CGF.Int8PtrTy};
135   llvm::Constant *InvariantStart = CGF.CGM.getIntrinsic(InvStartID, ObjectPtr);
136 
137   // Emit a call with the size in bytes of the object.
138   CharUnits WidthChars = CGF.getContext().getTypeSizeInChars(D.getType());
139   uint64_t Width = WidthChars.getQuantity();
140   llvm::Value *Args[2] = { llvm::ConstantInt::getSigned(CGF.Int64Ty, Width),
141                            llvm::ConstantExpr::getBitCast(Addr, CGF.Int8PtrTy)};
142   CGF.Builder.CreateCall(InvariantStart, Args);
143 }
144 
145 void CodeGenFunction::EmitCXXGlobalVarDeclInit(const VarDecl &D,
146                                                llvm::Constant *DeclPtr,
147                                                bool PerformInit) {
148 
149   const Expr *Init = D.getInit();
150   QualType T = D.getType();
151 
152   // The address space of a static local variable (DeclPtr) may be different
153   // from the address space of the "this" argument of the constructor. In that
154   // case, we need an addrspacecast before calling the constructor.
155   //
156   // struct StructWithCtor {
157   //   __device__ StructWithCtor() {...}
158   // };
159   // __device__ void foo() {
160   //   __shared__ StructWithCtor s;
161   //   ...
162   // }
163   //
164   // For example, in the above CUDA code, the static local variable s has a
165   // "shared" address space qualifier, but the constructor of StructWithCtor
166   // expects "this" in the "generic" address space.
167   unsigned ExpectedAddrSpace = getContext().getTargetAddressSpace(T);
168   unsigned ActualAddrSpace = DeclPtr->getType()->getPointerAddressSpace();
169   if (ActualAddrSpace != ExpectedAddrSpace) {
170     llvm::Type *LTy = CGM.getTypes().ConvertTypeForMem(T);
171     llvm::PointerType *PTy = llvm::PointerType::get(LTy, ExpectedAddrSpace);
172     DeclPtr = llvm::ConstantExpr::getAddrSpaceCast(DeclPtr, PTy);
173   }
174 
175   ConstantAddress DeclAddr(DeclPtr, getContext().getDeclAlign(&D));
176 
177   if (!T->isReferenceType()) {
178     if (getLangOpts().OpenMP && !getLangOpts().OpenMPSimd &&
179         D.hasAttr<OMPThreadPrivateDeclAttr>()) {
180       (void)CGM.getOpenMPRuntime().emitThreadPrivateVarDefinition(
181           &D, DeclAddr, D.getAttr<OMPThreadPrivateDeclAttr>()->getLocation(),
182           PerformInit, this);
183     }
184     if (PerformInit)
185       EmitDeclInit(*this, D, DeclAddr);
186     if (CGM.isTypeConstant(D.getType(), true))
187       EmitDeclInvariant(*this, D, DeclPtr);
188     else
189       EmitDeclDestroy(*this, D, DeclAddr);
190     return;
191   }
192 
193   assert(PerformInit && "cannot have constant initializer which needs "
194          "destruction for reference");
195   RValue RV = EmitReferenceBindingToExpr(Init);
196   EmitStoreOfScalar(RV.getScalarVal(), DeclAddr, false, T);
197 }
198 
199 /// Create a stub function, suitable for being passed to atexit,
200 /// which passes the given address to the given destructor function.
201 llvm::Constant *CodeGenFunction::createAtExitStub(const VarDecl &VD,
202                                                   llvm::Constant *dtor,
203                                                   llvm::Constant *addr) {
204   // Get the destructor function type, void(*)(void).
205   llvm::FunctionType *ty = llvm::FunctionType::get(CGM.VoidTy, false);
206   SmallString<256> FnName;
207   {
208     llvm::raw_svector_ostream Out(FnName);
209     CGM.getCXXABI().getMangleContext().mangleDynamicAtExitDestructor(&VD, Out);
210   }
211 
212   const CGFunctionInfo &FI = CGM.getTypes().arrangeNullaryFunction();
213   llvm::Function *fn = CGM.CreateGlobalInitOrDestructFunction(ty, FnName.str(),
214                                                               FI,
215                                                               VD.getLocation());
216 
217   CodeGenFunction CGF(CGM);
218 
219   CGF.StartFunction(&VD, CGM.getContext().VoidTy, fn, FI, FunctionArgList());
220 
221   llvm::CallInst *call = CGF.Builder.CreateCall(dtor, addr);
222 
223  // Make sure the call and the callee agree on calling convention.
224   if (llvm::Function *dtorFn =
225         dyn_cast<llvm::Function>(dtor->stripPointerCasts()))
226     call->setCallingConv(dtorFn->getCallingConv());
227 
228   CGF.FinishFunction();
229 
230   return fn;
231 }
232 
233 /// Register a global destructor using the C atexit runtime function.
234 void CodeGenFunction::registerGlobalDtorWithAtExit(const VarDecl &VD,
235                                                    llvm::Constant *dtor,
236                                                    llvm::Constant *addr) {
237   // Create a function which calls the destructor.
238   llvm::Constant *dtorStub = createAtExitStub(VD, dtor, addr);
239   registerGlobalDtorWithAtExit(dtorStub);
240 }
241 
242 void CodeGenFunction::registerGlobalDtorWithAtExit(llvm::Constant *dtorStub) {
243   // extern "C" int atexit(void (*f)(void));
244   llvm::FunctionType *atexitTy =
245     llvm::FunctionType::get(IntTy, dtorStub->getType(), false);
246 
247   llvm::Constant *atexit =
248       CGM.CreateRuntimeFunction(atexitTy, "atexit", llvm::AttributeList(),
249                                 /*Local=*/true);
250   if (llvm::Function *atexitFn = dyn_cast<llvm::Function>(atexit))
251     atexitFn->setDoesNotThrow();
252 
253   EmitNounwindRuntimeCall(atexit, dtorStub);
254 }
255 
256 void CodeGenFunction::EmitCXXGuardedInit(const VarDecl &D,
257                                          llvm::GlobalVariable *DeclPtr,
258                                          bool PerformInit) {
259   // If we've been asked to forbid guard variables, emit an error now.
260   // This diagnostic is hard-coded for Darwin's use case;  we can find
261   // better phrasing if someone else needs it.
262   if (CGM.getCodeGenOpts().ForbidGuardVariables)
263     CGM.Error(D.getLocation(),
264               "this initialization requires a guard variable, which "
265               "the kernel does not support");
266 
267   CGM.getCXXABI().EmitGuardedInit(*this, D, DeclPtr, PerformInit);
268 }
269 
270 void CodeGenFunction::EmitCXXGuardedInitBranch(llvm::Value *NeedsInit,
271                                                llvm::BasicBlock *InitBlock,
272                                                llvm::BasicBlock *NoInitBlock,
273                                                GuardKind Kind,
274                                                const VarDecl *D) {
275   assert((Kind == GuardKind::TlsGuard || D) && "no guarded variable");
276 
277   // A guess at how many times we will enter the initialization of a
278   // variable, depending on the kind of variable.
279   static const uint64_t InitsPerTLSVar = 1024;
280   static const uint64_t InitsPerLocalVar = 1024 * 1024;
281 
282   llvm::MDNode *Weights;
283   if (Kind == GuardKind::VariableGuard && !D->isLocalVarDecl()) {
284     // For non-local variables, don't apply any weighting for now. Due to our
285     // use of COMDATs, we expect there to be at most one initialization of the
286     // variable per DSO, but we have no way to know how many DSOs will try to
287     // initialize the variable.
288     Weights = nullptr;
289   } else {
290     uint64_t NumInits;
291     // FIXME: For the TLS case, collect and use profiling information to
292     // determine a more accurate brach weight.
293     if (Kind == GuardKind::TlsGuard || D->getTLSKind())
294       NumInits = InitsPerTLSVar;
295     else
296       NumInits = InitsPerLocalVar;
297 
298     // The probability of us entering the initializer is
299     //   1 / (total number of times we attempt to initialize the variable).
300     llvm::MDBuilder MDHelper(CGM.getLLVMContext());
301     Weights = MDHelper.createBranchWeights(1, NumInits - 1);
302   }
303 
304   Builder.CreateCondBr(NeedsInit, InitBlock, NoInitBlock, Weights);
305 }
306 
307 llvm::Function *CodeGenModule::CreateGlobalInitOrDestructFunction(
308     llvm::FunctionType *FTy, const Twine &Name, const CGFunctionInfo &FI,
309     SourceLocation Loc, bool TLS) {
310   llvm::Function *Fn =
311     llvm::Function::Create(FTy, llvm::GlobalValue::InternalLinkage,
312                            Name, &getModule());
313   if (!getLangOpts().AppleKext && !TLS) {
314     // Set the section if needed.
315     if (const char *Section = getTarget().getStaticInitSectionSpecifier())
316       Fn->setSection(Section);
317   }
318 
319   SetInternalFunctionAttributes(GlobalDecl(), Fn, FI);
320 
321   Fn->setCallingConv(getRuntimeCC());
322 
323   if (!getLangOpts().Exceptions)
324     Fn->setDoesNotThrow();
325 
326   if (getLangOpts().Sanitize.has(SanitizerKind::Address) &&
327       !isInSanitizerBlacklist(SanitizerKind::Address, Fn, Loc))
328     Fn->addFnAttr(llvm::Attribute::SanitizeAddress);
329 
330   if (getLangOpts().Sanitize.has(SanitizerKind::KernelAddress) &&
331       !isInSanitizerBlacklist(SanitizerKind::KernelAddress, Fn, Loc))
332     Fn->addFnAttr(llvm::Attribute::SanitizeAddress);
333 
334   if (getLangOpts().Sanitize.has(SanitizerKind::HWAddress) &&
335       !isInSanitizerBlacklist(SanitizerKind::HWAddress, Fn, Loc))
336     Fn->addFnAttr(llvm::Attribute::SanitizeHWAddress);
337 
338   if (getLangOpts().Sanitize.has(SanitizerKind::KernelHWAddress) &&
339       !isInSanitizerBlacklist(SanitizerKind::KernelHWAddress, Fn, Loc))
340     Fn->addFnAttr(llvm::Attribute::SanitizeHWAddress);
341 
342   if (getLangOpts().Sanitize.has(SanitizerKind::Thread) &&
343       !isInSanitizerBlacklist(SanitizerKind::Thread, Fn, Loc))
344     Fn->addFnAttr(llvm::Attribute::SanitizeThread);
345 
346   if (getLangOpts().Sanitize.has(SanitizerKind::Memory) &&
347       !isInSanitizerBlacklist(SanitizerKind::Memory, Fn, Loc))
348     Fn->addFnAttr(llvm::Attribute::SanitizeMemory);
349 
350   if (getLangOpts().Sanitize.has(SanitizerKind::KernelMemory) &&
351       !isInSanitizerBlacklist(SanitizerKind::KernelMemory, Fn, Loc))
352     Fn->addFnAttr(llvm::Attribute::SanitizeMemory);
353 
354   if (getLangOpts().Sanitize.has(SanitizerKind::SafeStack) &&
355       !isInSanitizerBlacklist(SanitizerKind::SafeStack, Fn, Loc))
356     Fn->addFnAttr(llvm::Attribute::SafeStack);
357 
358   if (getLangOpts().Sanitize.has(SanitizerKind::ShadowCallStack) &&
359       !isInSanitizerBlacklist(SanitizerKind::ShadowCallStack, Fn, Loc))
360     Fn->addFnAttr(llvm::Attribute::ShadowCallStack);
361 
362   auto RASignKind = getCodeGenOpts().getSignReturnAddress();
363   if (RASignKind != CodeGenOptions::SignReturnAddressScope::None) {
364     Fn->addFnAttr("sign-return-address",
365                   RASignKind == CodeGenOptions::SignReturnAddressScope::All
366                       ? "all"
367                       : "non-leaf");
368     auto RASignKey = getCodeGenOpts().getSignReturnAddressKey();
369     Fn->addFnAttr("sign-return-address-key",
370                   RASignKey == CodeGenOptions::SignReturnAddressKeyValue::AKey
371                       ? "a_key"
372                       : "b_key");
373   }
374 
375   if (getCodeGenOpts().BranchTargetEnforcement)
376     Fn->addFnAttr("branch-target-enforcement");
377 
378   return Fn;
379 }
380 
381 /// Create a global pointer to a function that will initialize a global
382 /// variable.  The user has requested that this pointer be emitted in a specific
383 /// section.
384 void CodeGenModule::EmitPointerToInitFunc(const VarDecl *D,
385                                           llvm::GlobalVariable *GV,
386                                           llvm::Function *InitFunc,
387                                           InitSegAttr *ISA) {
388   llvm::GlobalVariable *PtrArray = new llvm::GlobalVariable(
389       TheModule, InitFunc->getType(), /*isConstant=*/true,
390       llvm::GlobalValue::PrivateLinkage, InitFunc, "__cxx_init_fn_ptr");
391   PtrArray->setSection(ISA->getSection());
392   addUsedGlobal(PtrArray);
393 
394   // If the GV is already in a comdat group, then we have to join it.
395   if (llvm::Comdat *C = GV->getComdat())
396     PtrArray->setComdat(C);
397 }
398 
399 void
400 CodeGenModule::EmitCXXGlobalVarDeclInitFunc(const VarDecl *D,
401                                             llvm::GlobalVariable *Addr,
402                                             bool PerformInit) {
403 
404   // According to E.2.3.1 in CUDA-7.5 Programming guide: __device__,
405   // __constant__ and __shared__ variables defined in namespace scope,
406   // that are of class type, cannot have a non-empty constructor. All
407   // the checks have been done in Sema by now. Whatever initializers
408   // are allowed are empty and we just need to ignore them here.
409   if (getLangOpts().CUDA && getLangOpts().CUDAIsDevice &&
410       (D->hasAttr<CUDADeviceAttr>() || D->hasAttr<CUDAConstantAttr>() ||
411        D->hasAttr<CUDASharedAttr>()))
412     return;
413 
414   if (getLangOpts().OpenMP &&
415       getOpenMPRuntime().emitDeclareTargetVarDefinition(D, Addr, PerformInit))
416     return;
417 
418   // Check if we've already initialized this decl.
419   auto I = DelayedCXXInitPosition.find(D);
420   if (I != DelayedCXXInitPosition.end() && I->second == ~0U)
421     return;
422 
423   llvm::FunctionType *FTy = llvm::FunctionType::get(VoidTy, false);
424   SmallString<256> FnName;
425   {
426     llvm::raw_svector_ostream Out(FnName);
427     getCXXABI().getMangleContext().mangleDynamicInitializer(D, Out);
428   }
429 
430   // Create a variable initialization function.
431   llvm::Function *Fn =
432       CreateGlobalInitOrDestructFunction(FTy, FnName.str(),
433                                          getTypes().arrangeNullaryFunction(),
434                                          D->getLocation());
435 
436   auto *ISA = D->getAttr<InitSegAttr>();
437   CodeGenFunction(*this).GenerateCXXGlobalVarDeclInitFunc(Fn, D, Addr,
438                                                           PerformInit);
439 
440   llvm::GlobalVariable *COMDATKey =
441       supportsCOMDAT() && D->isExternallyVisible() ? Addr : nullptr;
442 
443   if (D->getTLSKind()) {
444     // FIXME: Should we support init_priority for thread_local?
445     // FIXME: We only need to register one __cxa_thread_atexit function for the
446     // entire TU.
447     CXXThreadLocalInits.push_back(Fn);
448     CXXThreadLocalInitVars.push_back(D);
449   } else if (PerformInit && ISA) {
450     EmitPointerToInitFunc(D, Addr, Fn, ISA);
451   } else if (auto *IPA = D->getAttr<InitPriorityAttr>()) {
452     OrderGlobalInits Key(IPA->getPriority(), PrioritizedCXXGlobalInits.size());
453     PrioritizedCXXGlobalInits.push_back(std::make_pair(Key, Fn));
454   } else if (isTemplateInstantiation(D->getTemplateSpecializationKind())) {
455     // C++ [basic.start.init]p2:
456     //   Definitions of explicitly specialized class template static data
457     //   members have ordered initialization. Other class template static data
458     //   members (i.e., implicitly or explicitly instantiated specializations)
459     //   have unordered initialization.
460     //
461     // As a consequence, we can put them into their own llvm.global_ctors entry.
462     //
463     // If the global is externally visible, put the initializer into a COMDAT
464     // group with the global being initialized.  On most platforms, this is a
465     // minor startup time optimization.  In the MS C++ ABI, there are no guard
466     // variables, so this COMDAT key is required for correctness.
467     AddGlobalCtor(Fn, 65535, COMDATKey);
468   } else if (D->hasAttr<SelectAnyAttr>()) {
469     // SelectAny globals will be comdat-folded. Put the initializer into a
470     // COMDAT group associated with the global, so the initializers get folded
471     // too.
472     AddGlobalCtor(Fn, 65535, COMDATKey);
473   } else {
474     I = DelayedCXXInitPosition.find(D); // Re-do lookup in case of re-hash.
475     if (I == DelayedCXXInitPosition.end()) {
476       CXXGlobalInits.push_back(Fn);
477     } else if (I->second != ~0U) {
478       assert(I->second < CXXGlobalInits.size() &&
479              CXXGlobalInits[I->second] == nullptr);
480       CXXGlobalInits[I->second] = Fn;
481     }
482   }
483 
484   // Remember that we already emitted the initializer for this global.
485   DelayedCXXInitPosition[D] = ~0U;
486 }
487 
488 void CodeGenModule::EmitCXXThreadLocalInitFunc() {
489   getCXXABI().EmitThreadLocalInitFuncs(
490       *this, CXXThreadLocals, CXXThreadLocalInits, CXXThreadLocalInitVars);
491 
492   CXXThreadLocalInits.clear();
493   CXXThreadLocalInitVars.clear();
494   CXXThreadLocals.clear();
495 }
496 
497 void
498 CodeGenModule::EmitCXXGlobalInitFunc() {
499   while (!CXXGlobalInits.empty() && !CXXGlobalInits.back())
500     CXXGlobalInits.pop_back();
501 
502   if (CXXGlobalInits.empty() && PrioritizedCXXGlobalInits.empty())
503     return;
504 
505   llvm::FunctionType *FTy = llvm::FunctionType::get(VoidTy, false);
506   const CGFunctionInfo &FI = getTypes().arrangeNullaryFunction();
507 
508   // Create our global initialization function.
509   if (!PrioritizedCXXGlobalInits.empty()) {
510     SmallVector<llvm::Function *, 8> LocalCXXGlobalInits;
511     llvm::array_pod_sort(PrioritizedCXXGlobalInits.begin(),
512                          PrioritizedCXXGlobalInits.end());
513     // Iterate over "chunks" of ctors with same priority and emit each chunk
514     // into separate function. Note - everything is sorted first by priority,
515     // second - by lex order, so we emit ctor functions in proper order.
516     for (SmallVectorImpl<GlobalInitData >::iterator
517            I = PrioritizedCXXGlobalInits.begin(),
518            E = PrioritizedCXXGlobalInits.end(); I != E; ) {
519       SmallVectorImpl<GlobalInitData >::iterator
520         PrioE = std::upper_bound(I + 1, E, *I, GlobalInitPriorityCmp());
521 
522       LocalCXXGlobalInits.clear();
523       unsigned Priority = I->first.priority;
524       // Compute the function suffix from priority. Prepend with zeroes to make
525       // sure the function names are also ordered as priorities.
526       std::string PrioritySuffix = llvm::utostr(Priority);
527       // Priority is always <= 65535 (enforced by sema).
528       PrioritySuffix = std::string(6-PrioritySuffix.size(), '0')+PrioritySuffix;
529       llvm::Function *Fn = CreateGlobalInitOrDestructFunction(
530           FTy, "_GLOBAL__I_" + PrioritySuffix, FI);
531 
532       for (; I < PrioE; ++I)
533         LocalCXXGlobalInits.push_back(I->second);
534 
535       CodeGenFunction(*this).GenerateCXXGlobalInitFunc(Fn, LocalCXXGlobalInits);
536       AddGlobalCtor(Fn, Priority);
537     }
538     PrioritizedCXXGlobalInits.clear();
539   }
540 
541   // Include the filename in the symbol name. Including "sub_" matches gcc and
542   // makes sure these symbols appear lexicographically behind the symbols with
543   // priority emitted above.
544   SmallString<128> FileName = llvm::sys::path::filename(getModule().getName());
545   if (FileName.empty())
546     FileName = "<null>";
547 
548   for (size_t i = 0; i < FileName.size(); ++i) {
549     // Replace everything that's not [a-zA-Z0-9._] with a _. This set happens
550     // to be the set of C preprocessing numbers.
551     if (!isPreprocessingNumberBody(FileName[i]))
552       FileName[i] = '_';
553   }
554 
555   llvm::Function *Fn = CreateGlobalInitOrDestructFunction(
556       FTy, llvm::Twine("_GLOBAL__sub_I_", FileName), FI);
557 
558   CodeGenFunction(*this).GenerateCXXGlobalInitFunc(Fn, CXXGlobalInits);
559   AddGlobalCtor(Fn);
560 
561   CXXGlobalInits.clear();
562 }
563 
564 void CodeGenModule::EmitCXXGlobalDtorFunc() {
565   if (CXXGlobalDtors.empty())
566     return;
567 
568   llvm::FunctionType *FTy = llvm::FunctionType::get(VoidTy, false);
569 
570   // Create our global destructor function.
571   const CGFunctionInfo &FI = getTypes().arrangeNullaryFunction();
572   llvm::Function *Fn =
573       CreateGlobalInitOrDestructFunction(FTy, "_GLOBAL__D_a", FI);
574 
575   CodeGenFunction(*this).GenerateCXXGlobalDtorsFunc(Fn, CXXGlobalDtors);
576   AddGlobalDtor(Fn);
577 }
578 
579 /// Emit the code necessary to initialize the given global variable.
580 void CodeGenFunction::GenerateCXXGlobalVarDeclInitFunc(llvm::Function *Fn,
581                                                        const VarDecl *D,
582                                                  llvm::GlobalVariable *Addr,
583                                                        bool PerformInit) {
584   // Check if we need to emit debug info for variable initializer.
585   if (D->hasAttr<NoDebugAttr>())
586     DebugInfo = nullptr; // disable debug info indefinitely for this function
587 
588   CurEHLocation = D->getBeginLoc();
589 
590   StartFunction(GlobalDecl(D), getContext().VoidTy, Fn,
591                 getTypes().arrangeNullaryFunction(),
592                 FunctionArgList(), D->getLocation(),
593                 D->getInit()->getExprLoc());
594 
595   // Use guarded initialization if the global variable is weak. This
596   // occurs for, e.g., instantiated static data members and
597   // definitions explicitly marked weak.
598   if (Addr->hasWeakLinkage() || Addr->hasLinkOnceLinkage()) {
599     EmitCXXGuardedInit(*D, Addr, PerformInit);
600   } else {
601     EmitCXXGlobalVarDeclInit(*D, Addr, PerformInit);
602   }
603 
604   FinishFunction();
605 }
606 
607 void
608 CodeGenFunction::GenerateCXXGlobalInitFunc(llvm::Function *Fn,
609                                            ArrayRef<llvm::Function *> Decls,
610                                            Address Guard) {
611   {
612     auto NL = ApplyDebugLocation::CreateEmpty(*this);
613     StartFunction(GlobalDecl(), getContext().VoidTy, Fn,
614                   getTypes().arrangeNullaryFunction(), FunctionArgList());
615     // Emit an artificial location for this function.
616     auto AL = ApplyDebugLocation::CreateArtificial(*this);
617 
618     llvm::BasicBlock *ExitBlock = nullptr;
619     if (Guard.isValid()) {
620       // If we have a guard variable, check whether we've already performed
621       // these initializations. This happens for TLS initialization functions.
622       llvm::Value *GuardVal = Builder.CreateLoad(Guard);
623       llvm::Value *Uninit = Builder.CreateIsNull(GuardVal,
624                                                  "guard.uninitialized");
625       llvm::BasicBlock *InitBlock = createBasicBlock("init");
626       ExitBlock = createBasicBlock("exit");
627       EmitCXXGuardedInitBranch(Uninit, InitBlock, ExitBlock,
628                                GuardKind::TlsGuard, nullptr);
629       EmitBlock(InitBlock);
630       // Mark as initialized before initializing anything else. If the
631       // initializers use previously-initialized thread_local vars, that's
632       // probably supposed to be OK, but the standard doesn't say.
633       Builder.CreateStore(llvm::ConstantInt::get(GuardVal->getType(),1), Guard);
634     }
635 
636     RunCleanupsScope Scope(*this);
637 
638     // When building in Objective-C++ ARC mode, create an autorelease pool
639     // around the global initializers.
640     if (getLangOpts().ObjCAutoRefCount && getLangOpts().CPlusPlus) {
641       llvm::Value *token = EmitObjCAutoreleasePoolPush();
642       EmitObjCAutoreleasePoolCleanup(token);
643     }
644 
645     for (unsigned i = 0, e = Decls.size(); i != e; ++i)
646       if (Decls[i])
647         EmitRuntimeCall(Decls[i]);
648 
649     Scope.ForceCleanup();
650 
651     if (ExitBlock) {
652       Builder.CreateBr(ExitBlock);
653       EmitBlock(ExitBlock);
654     }
655   }
656 
657   FinishFunction();
658 }
659 
660 void CodeGenFunction::GenerateCXXGlobalDtorsFunc(
661     llvm::Function *Fn,
662     const std::vector<std::pair<llvm::WeakTrackingVH, llvm::Constant *>>
663         &DtorsAndObjects) {
664   {
665     auto NL = ApplyDebugLocation::CreateEmpty(*this);
666     StartFunction(GlobalDecl(), getContext().VoidTy, Fn,
667                   getTypes().arrangeNullaryFunction(), FunctionArgList());
668     // Emit an artificial location for this function.
669     auto AL = ApplyDebugLocation::CreateArtificial(*this);
670 
671     // Emit the dtors, in reverse order from construction.
672     for (unsigned i = 0, e = DtorsAndObjects.size(); i != e; ++i) {
673       llvm::Value *Callee = DtorsAndObjects[e - i - 1].first;
674       llvm::CallInst *CI = Builder.CreateCall(Callee,
675                                           DtorsAndObjects[e - i - 1].second);
676       // Make sure the call and the callee agree on calling convention.
677       if (llvm::Function *F = dyn_cast<llvm::Function>(Callee))
678         CI->setCallingConv(F->getCallingConv());
679     }
680   }
681 
682   FinishFunction();
683 }
684 
685 /// generateDestroyHelper - Generates a helper function which, when
686 /// invoked, destroys the given object.  The address of the object
687 /// should be in global memory.
688 llvm::Function *CodeGenFunction::generateDestroyHelper(
689     Address addr, QualType type, Destroyer *destroyer,
690     bool useEHCleanupForArray, const VarDecl *VD) {
691   FunctionArgList args;
692   ImplicitParamDecl Dst(getContext(), getContext().VoidPtrTy,
693                         ImplicitParamDecl::Other);
694   args.push_back(&Dst);
695 
696   const CGFunctionInfo &FI =
697     CGM.getTypes().arrangeBuiltinFunctionDeclaration(getContext().VoidTy, args);
698   llvm::FunctionType *FTy = CGM.getTypes().GetFunctionType(FI);
699   llvm::Function *fn = CGM.CreateGlobalInitOrDestructFunction(
700       FTy, "__cxx_global_array_dtor", FI, VD->getLocation());
701 
702   CurEHLocation = VD->getBeginLoc();
703 
704   StartFunction(VD, getContext().VoidTy, fn, FI, args);
705 
706   emitDestroy(addr, type, destroyer, useEHCleanupForArray);
707 
708   FinishFunction();
709 
710   return fn;
711 }
712